	INCLUDE EFR32MG12.inc			; CPU register definitions
	INCLUDE	i2c.inc	
	IMPORT	I2Cbuf	

CCS811_SLAVE_ADDRESS	EQU	0x5A    	; sensor slave address

;-------------------------------------	; non-initialized DATA segment in RAM 
	AREA	RAM, DATA, NOINIT, READWRITE, ALIGN=3
co2	SPACE	2
tvoc	SPACE	2	
	EXPORT	co2
	EXPORT	tvoc				
		
	AREA    |.text|, CODE, READONLY		; another section in the CODE area	
;-------------------------------------------------------------------------------
CCS811_setup	PROC
	EXPORT	CCS811_setup
	push	{LR, R0-R2}			; save used regs
	OORW	0x441<<20, GPIO_PF_MODEH, GPIO	; enable power to CCS811
	OORW	1<<14, GPIO_PF_DOUT	
	PUTW	5<<20, GPIO_EXTIPSELH		; select PORTF for interrupt 13
	PUTW	1<<20, GPIO_EXTIPINSELH		; select pin 13 for interrupt
	PUTW	1<<13, GPIO_EXTIFALL		; select falling edge for interrupt 13
	PUTW	1<<13, GPIO_IEN			; enable interupt 13
	OORW	1<<18, 0, NVIC_ISER0		; enable odd  port pins interrupt in NVIC	
	
	ldr	R0, =1000000
ss1	subs	R0, #1				; power-up delay
	bne	ss1		
	
	mov	R0, #CCS811_SLAVE_ADDRESS	; get status
	ldr	R1, =I2Cbuf
	mov	R2, #1				; read 1 status byte
	mov	R3, #0				; status reg address
	bl	I2CMasterReadBuf		; get status

	mov	R0, #CCS811_SLAVE_ADDRESS	; move to APP mode
	ldr	R1, =I2Cbuf
	mov	R2, #0xF4			; write 1 byte
	strb	R2, [R1]
	mov	R2, #1
	bl	I2CMasterWriteBuf		

	ldr	R0, =1000000
ss2	subs	R0, #1				; power-up delay 2
	bne	ss2
	
	mov	R0, #CCS811_SLAVE_ADDRESS	; get status
	ldr	R1, =I2Cbuf
	mov	R2, #1				; read 1 status byte
	mov	R3, #0				; status reg address
	bl	I2CMasterReadBuf		; get status	
	
	PUTB	0x01, 0, I2Cbuf			; measure mode reg address
	PUTB	0x18, 1				; 1sec period, interrupt enabled
	mov	R0, #CCS811_SLAVE_ADDRESS
	ldr	R1, =I2Cbuf
	mov	R2, #2
	bl	I2CMasterWriteBuf
	
	pop	{PC, R0-R2}
	ENDP
				
;-------------------------------------------------------------------------------
CCS811_get_data	PROC
	EXPORT	CCS811_get_data
	push	{LR, R0-R2}			; save used regs
	mov	R0, #CCS811_SLAVE_ADDRESS
	ldr	R1, =I2Cbuf
	mov	R2, #4				; read 4 bytes
	mov	R3, #2				; data reg address
	bl	I2CMasterReadBuf

	ldr	R0, =co2
	ldrh	R2, [R1]			; read CO2 value (ppm)
	rev16	R2, R2				; reverse bytes order
	strh	R2, [R0]			; save CO2 value in RAM
	ldr	R2, [R1, #2]			; read TVOC value
	rev16	R2, R2
	str	R2, [R0, #2]			; save TVOC value in RAM	
	pop	{PC, R0-R2}
	ENDP

	ALIGN
	END	